@@ -1,4 +1,4 @@
-/* Copyright 2000-2004 The Apache Software Foundation
+/* Copyright 2000-2005 The Apache Software Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -96,19 +96,11 @@ SV *modperl_slurp_filename(pTHX_ request_rec *r, int tainted);
 
 char *modperl_file2package(apr_pool_t *p, const char *file);
 
-/**
- * convert a compiled *CV ref to its original source code
- * @param p       pool object (with a shortest possible life scope)
- * @param cv      compiled *CV
- * @return string of original source code
- */
-char *modperl_coderef2text(pTHX_ apr_pool_t *p, CV *cv);
-
 SV *modperl_apr_array_header2avrv(pTHX_ apr_array_header_t *array);
 apr_array_header_t *modperl_avrv2apr_array_header(pTHX_ apr_pool_t *p,
                                                   SV *avrv);
 void modperl_package_unload(pTHX_ const char *package);
-#if defined(MP_TRACE) && defined(APR_HAS_THREADS)
+#if defined(MP_TRACE) && APR_HAS_THREADS
 #define MP_TRACEf_TID   "/tid 0x%lx"
 #define MP_TRACEv_TID   (unsigned long)apr_os_thread_current()
 #define MP_TRACEv_TID_  MP_TRACEv_TID,
@@ -147,4 +139,10 @@ void modperl_package_unload(pTHX_ const char *package);
         : (char *)apr_psprintf(p, "%s...",                               \
                                apr_pstrmemdup(p, str, MP_TRACE_STR_LEN))
 
+/* functions maintaining the amount of times mod_perl was restarted,
+ * e.g. on Apache start, it restarts itself, so the count will be
+ * first 1, and on on restart 2 */
+void modperl_restart_count_inc(server_rec *base_server);
+int  modperl_restart_count(void);
+
 #endif /* MODPERL_UTIL_H */
